@@ -2,3 +2,7 @@ from .psp import psp
 from .view import View
 from .aggregate import Aggregate
 from .exception import PSPException
+
+from .widget import PerspectiveWidget
+
+__version__ = '0.0.12'
